# Tiny-URL-Wrapper
This repository is an API wrapper made in Python for Tiny-URL.

# Usage
```python
from tiny_url import Tiny

url = "https://www.google.com"
t = Tiny.make_url(url)
print(t)
```

`Copyright (c) 2022 minato37103710`
